@@ -1,6 +1,6 @@
 require 'test_helper'
 
-class I18nCascadeApiTest < Test::Unit::TestCase
+class I18nCascadeApiTest < I18n::TestCase
   class Backend < I18n::Backend::Simple
     include I18n::Backend::Cascade
   end
